summaryrefslogtreecommitdiff
path: root/tests/expressions
diff options
context:
space:
mode:
authorSimon Charette <charette.s@gmail.com>2020-08-30 22:25:54 -0400
committerMariusz Felisiak <felisiak.mariusz@gmail.com>2020-08-31 06:42:40 +0200
commit38fce49c82858d2cac810679d1c0e518840a8615 (patch)
treeeeb1dd0d864c1dd83882792e21ade5b93d7f6cc7 /tests/expressions
parent40894f29675b02be9597c3af358ed490d2b96651 (diff)
downloaddjango-38fce49c82858d2cac810679d1c0e518840a8615.tar.gz
Fixed #31919 -- Resolved output_field of IntegerField subclasses combinations.
Diffstat (limited to 'tests/expressions')
-rw-r--r--tests/expressions/tests.py6
1 files changed, 4 insertions, 2 deletions
diff --git a/tests/expressions/tests.py b/tests/expressions/tests.py
index 42b6b828f4..0ae61a6506 100644
--- a/tests/expressions/tests.py
+++ b/tests/expressions/tests.py
@@ -9,8 +9,8 @@ from unittest import mock
from django.core.exceptions import FieldError
from django.db import DatabaseError, NotSupportedError, connection
from django.db.models import (
Avg, BinaryField, BooleanField, Case, CharField, Count, DateField,
DateTimeField, DecimalField, DurationField, Exists, Expression,
ExpressionList, ExpressionWrapper, F, FloatField, Func, IntegerField, Max,
Min, Model, OrderBy, OuterRef, Q, StdDev, Subquery, Sum, TimeField,
UUIDField, Value, Variance, When,
@@ -1893,6 +1893,8 @@ class CombinableTests(SimpleTestCase):
class CombinedExpressionTests(SimpleTestCase):
def test_resolve_output_field(self):
tests = [
+ (IntegerField, AutoField, IntegerField),
+ (AutoField, IntegerField, IntegerField),
(IntegerField, DecimalField, DecimalField),
(DecimalField, IntegerField, DecimalField),
(IntegerField, FloatField, FloatField),
@@ -9,8 +9,8 @@ from unittest import mock
from django.db import DatabaseError, NotSupportedError, connection
from django.db.models import (
- Avg, BinaryField, BooleanField, Case, CharField, Count, DateField,
- DateTimeField, DecimalField, DurationField, Exists, Expression,
+ AutoField, Avg, BinaryField, BooleanField, Case, CharField, Count,
+ DateField, DateTimeField, DecimalField, DurationField, Exists, Expression,
ExpressionList, ExpressionWrapper, F, FloatField, Func, IntegerField, Max,
Min, Model, OrderBy, OuterRef, Q, StdDev, Subquery, Sum, TimeField,